@@ -1,5 +1,5 @@
 /*
- *   Copyright (C) 2007-2017 Tristan Heaven <tristan@tristanheaven.net>
+ *   Copyright (C) 2007-2020 Tristan Heaven <tristan@tristanheaven.net>
  *
  *   This file is part of GtkHash.
  *
@@ -46,13 +46,13 @@ static bool on_window_delete_event(void)
 
 static void on_menuitem_open_activate(void)
 {
-#if GTK_CHECK_VERSION(3,20,0)
+#if (GTK_CHECK_VERSION(3,20,0) && ENABLE_NATIVE_FILE_CHOOSER)
 	GtkFileChooser *chooser = GTK_FILE_CHOOSER(gtk_file_chooser_native_new(
-		_("Check Digests"), gui.window, GTK_FILE_CHOOSER_ACTION_OPEN,
+		_("Open Digest File"), gui.window, GTK_FILE_CHOOSER_ACTION_OPEN,
 		_("_Open"), _("_Cancel")));
 #else
 	GtkFileChooser *chooser = GTK_FILE_CHOOSER(
-		gtk_file_chooser_dialog_new(_("Check Digests"), gui.window,
+		gtk_file_chooser_dialog_new(_("Open Digest File"), gui.window,
 			GTK_FILE_CHOOSER_ACTION_OPEN,
 			_("_Cancel"), GTK_RESPONSE_CANCEL,
 			_("_Open"), GTK_RESPONSE_ACCEPT,
@@ -63,14 +63,14 @@ static void on_menuitem_open_activate(void)
 	gtk_file_chooser_set_local_only(chooser, false);
 
 #ifndef G_OS_WIN32
-	/* Note: Adding filters causes GTK+ to fallback to GtkFileChooserDialog.
+	/* Note: Adding filters causes GTK to fallback to GtkFileChooserDialog.
 	   On Windows, having a native file chooser is definitely preferable. */
 
 	GtkFileFilter *filter = NULL;
 
 	filter = gtk_file_filter_new();
 	gtk_file_filter_set_name(filter,
-		_("Digest/Checksum Files (*.sha1, *.md5, *.sfv, ...)"));
+		_("Digest/Checksum Files (*.sha1, *.md5, *.sfv, …)"));
 	check_file_add_filters(filter);
 	gtk_file_chooser_add_filter(chooser, filter);
 
@@ -80,7 +80,7 @@ static void on_menuitem_open_activate(void)
 	gtk_file_chooser_add_filter(chooser, filter);
 #endif
 
-#if GTK_CHECK_VERSION(3,20,0)
+#if (GTK_CHECK_VERSION(3,20,0) && ENABLE_NATIVE_FILE_CHOOSER)
 	if (gtk_native_dialog_run(GTK_NATIVE_DIALOG(chooser)) == GTK_RESPONSE_ACCEPT) {
 #else
 	if (gtk_dialog_run(GTK_DIALOG(chooser)) == GTK_RESPONSE_ACCEPT) {
@@ -106,7 +106,7 @@ static void on_menuitem_open_activate(void)
 		g_slist_free_full(files, g_object_unref);
 	}
 
-#if GTK_CHECK_VERSION(3,20,0)
+#if (GTK_CHECK_VERSION(3,20,0) && ENABLE_NATIVE_FILE_CHOOSER)
 	g_object_unref(chooser);
 #else
 	gtk_widget_destroy(GTK_WIDGET(chooser));
@@ -115,13 +115,13 @@ static void on_menuitem_open_activate(void)
 
 static void on_menuitem_save_as_activate(void)
 {
-#if GTK_CHECK_VERSION(3,20,0)
+#if (GTK_CHECK_VERSION(3,20,0) && ENABLE_NATIVE_FILE_CHOOSER)
 	GtkFileChooser *chooser = GTK_FILE_CHOOSER(gtk_file_chooser_native_new(
-		_("Save Digests"), gui.window, GTK_FILE_CHOOSER_ACTION_SAVE,
+		_("Save Digest File"), gui.window, GTK_FILE_CHOOSER_ACTION_SAVE,
 		_("_Save"), _("_Cancel")));
 #else
 	GtkFileChooser *chooser = GTK_FILE_CHOOSER(
-		gtk_file_chooser_dialog_new(_("Save Digests"), gui.window,
+		gtk_file_chooser_dialog_new(_("Save Digest File"), gui.window,
 			GTK_FILE_CHOOSER_ACTION_SAVE,
 			_("_Cancel"), GTK_RESPONSE_CANCEL,
 			_("_Save"), GTK_RESPONSE_ACCEPT,
@@ -132,7 +132,7 @@ static void on_menuitem_save_as_activate(void)
 	gtk_file_chooser_set_local_only(chooser, true); // TODO
 	gtk_file_chooser_set_do_overwrite_confirmation(chooser, true);
 
-#if GTK_CHECK_VERSION(3,20,0)
+#if (GTK_CHECK_VERSION(3,20,0) && ENABLE_NATIVE_FILE_CHOOSER)
 	if (gtk_native_dialog_run(GTK_NATIVE_DIALOG(chooser)) == GTK_RESPONSE_ACCEPT) {
 #else
 	if (gtk_dialog_run(GTK_DIALOG(chooser)) == GTK_RESPONSE_ACCEPT) {
@@ -142,7 +142,7 @@ static void on_menuitem_save_as_activate(void)
 		g_free(filename);
 	}
 
-#if GTK_CHECK_VERSION(3,20,0)
+#if (GTK_CHECK_VERSION(3,20,0) && ENABLE_NATIVE_FILE_CHOOSER)
 	g_object_unref(chooser);
 #else
 	gtk_widget_destroy(GTK_WIDGET(chooser));
@@ -243,34 +243,15 @@ static void on_radiomenuitem_toggled(void)
 		view = GUI_VIEW_FILE_LIST;
 	}
 
-	g_assert(GUI_VIEW_IS_VALID(view));
-
-	if (gui.view != view) {
-		gui.view = view;
-		gui_update();
-	}
+	gui_set_view(view);
+	gui_update();
 }
 
 static void on_menuitem_about_activate(void)
 {
-#if (GTK_MAJOR_VERSION < 3)
-	static const char * const license = {
-		"This program is free software: you can redistribute it and/or modify\n"
-		"it under the terms of the GNU General Public License as published by\n"
-		"the Free Software Foundation, either version 2 of the License, or\n"
-		"(at your option) any later version.\n\n"
-		"This program is distributed in the hope that it will be useful,\n"
-		"but WITHOUT ANY WARRANTY; without even the implied warranty of\n"
-		"MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the\n"
-		"GNU General Public License for more details.\n\n"
-		"You should have received a copy of the GNU General Public License along\n"
-		"with this program; if not, see <https://gnu.org/licenses/gpl-2.0.txt>.\n"
-	};
-#endif
-
 	static const char * const artists[] = {
-		"Icon derived from GTK+ Logo "
-		"https://wiki.gnome.org/Projects/GTK%2B/Logo",
+		"Icon derived from GTK Logo "
+		"https://wiki.gnome.org/Projects/GTK/Logo",
 		NULL
 	};
 
@@ -279,24 +260,29 @@ static void on_menuitem_about_activate(void)
 		NULL
 	};
 
+	const char *snap_version = NULL;
+	if (g_strcmp0(g_getenv("SNAP_NAME"), PACKAGE) == 0)
+		snap_version = g_getenv("SNAP_VERSION");
+
+	char *version = g_markup_printf_escaped("%s",
+		snap_version ? snap_version : VERSION);
+
 	gtk_show_about_dialog(
 			gui.window,
 			"artists", artists,
 			"authors", authors,
-			"comments", _("A GTK+ utility for computing message digests or checksums."),
-#if (GTK_MAJOR_VERSION > 2)
+			"comments", _("A desktop utility for computing message digests or checksums"),
 			"license-type", GTK_LICENSE_GPL_2_0,
-#else
-			"license", license,
-#endif
-			"logo-icon-name", PACKAGE,
+			"logo-icon-name", "org.gtkhash.gtkhash",
 			"program-name", PACKAGE_NAME,
 #if ENABLE_NLS
 			"translator-credits", _("translator-credits"),
 #endif
-			"version", VERSION,
+			"version", version,
 			"website", "https://github.com/tristanheaven/gtkhash",
 			NULL);
+
+	g_free(version);
 }
 
 static void on_filechooserbutton_selection_changed(void)
@@ -316,7 +302,7 @@ static void on_filechooserbutton_selection_changed(void)
 
 static void on_toolbutton_add_clicked(void)
 {
-#if GTK_CHECK_VERSION(3,20,0)
+#if (GTK_CHECK_VERSION(3,20,0) && ENABLE_NATIVE_FILE_CHOOSER)
 	GtkFileChooser *chooser = GTK_FILE_CHOOSER(gtk_file_chooser_native_new(
 		_("Select Files"), gui.window, GTK_FILE_CHOOSER_ACTION_OPEN,
 		_("_Open"), _("_Cancel")));
@@ -332,7 +318,7 @@ static void on_toolbutton_add_clicked(void)
 	gtk_file_chooser_set_select_multiple(chooser, true);
 	gtk_file_chooser_set_local_only(chooser, false);
 
-#if GTK_CHECK_VERSION(3,20,0)
+#if (GTK_CHECK_VERSION(3,20,0) && ENABLE_NATIVE_FILE_CHOOSER)
 	if (gtk_native_dialog_run(GTK_NATIVE_DIALOG(chooser)) == GTK_RESPONSE_ACCEPT) {
 #else
 	if (gtk_dialog_run(GTK_DIALOG(chooser)) == GTK_RESPONSE_ACCEPT) {
@@ -346,7 +332,7 @@ static void on_toolbutton_add_clicked(void)
 		g_slist_free(uris);
 	}
 
-#if GTK_CHECK_VERSION(3,20,0)
+#if (GTK_CHECK_VERSION(3,20,0) && ENABLE_NATIVE_FILE_CHOOSER)
 	g_object_unref(chooser);
 #else
 	gtk_widget_destroy(GTK_WIDGET(chooser));
@@ -413,12 +399,7 @@ static void on_treeview_popup_menu(void)
 static bool on_treeview_button_press_event(G_GNUC_UNUSED GtkWidget *widget,
 	GdkEventButton *event)
 {
-#if (GTK_MAJOR_VERSION > 2)
-	if (gdk_event_triggers_context_menu((GdkEvent *)event))
-#else
-	if ((event->type == GDK_BUTTON_PRESS) && (event->button == 3))
-#endif
-	{
+	if (gdk_event_triggers_context_menu((GdkEvent *)event)) {
 		show_menu_treeview(event);
 		// Stop processing the event now so the selection won't be changed
 		return true;
@@ -448,7 +429,8 @@ static void on_treeview_drag_data_received(G_GNUC_UNUSED GtkWidget *widget,
 	gtk_drag_finish(context, true, true, t);
 }
 
-static void on_menuitem_treeview_copy_activate(struct hash_func_s *func)
+static void on_menuitem_treeview_copy_activate(G_GNUC_UNUSED GtkMenuItem *menuitem,
+	struct hash_func_s *func)
 {
 	char *digest = list_get_selected_digest(func->id);
 	g_assert(digest);
@@ -466,25 +448,50 @@ static void on_menuitem_treeview_show_toolbar_toggled(void)
 	gtk_widget_set_visible(GTK_WIDGET(gui.toolbar), show_toolbar);
 }
 
-static void on_button_hash_clicked(void)
+static void on_button_hash_clicked(G_GNUC_UNUSED GtkButton *button,
+	struct hash_func_s *func)
 {
 	if (gui.view == GUI_VIEW_FILE) {
-		// XXX: Workaround for when user clicks Cancel in FileChooserDialog and
-		// XXX: uri is changed without emitting the "selection-changed" signal
+		// Workaround for when user clicks Cancel in FileChooserDialog and
+		// uri is changed without emitting the "selection-changed" signal
 		on_filechooserbutton_selection_changed();
 		if (!gtk_widget_get_sensitive(GTK_WIDGET(gui.button_hash)))
 			return;
+
+		// Single-function hash
+		if (func) {
+			for (int i = 0; i < HASH_FUNCS_N; i++) {
+				if (!hash.funcs[i].supported || i == func->id)
+					continue;
+				hash.funcs[i].enabled = false;
+			}
+		}
 	}
 
 	gui_start_hash();
 }
 
+static void on_entry_check_icon_press(GtkEntry *entry,
+	GtkEntryIconPosition pos, GdkEventButton *event)
+{
+	if (pos != GTK_ENTRY_ICON_PRIMARY)
+		return;
+	if (event->type != GDK_BUTTON_PRESS)
+		return;
+	if (event->button != 1)
+		return;
+
+	gtk_entry_set_text(entry, "");
+	gtk_editable_paste_clipboard(GTK_EDITABLE(entry));
+}
+
 static void on_togglebutton_hmac_file_toggled(void)
 {
 	g_assert(gui.view == GUI_VIEW_FILE);
 
 	bool active = gtk_toggle_button_get_active(gui.togglebutton_hmac_file);
 	gtk_widget_set_sensitive(GTK_WIDGET(gui.entry_hmac_file), active);
+
 	gui_clear_digests();
 
 	gui_update_hash_func_labels(active);
@@ -519,8 +526,8 @@ static void on_entry_hmac_populate_popup(GtkEntry *entry, GtkMenu *menu)
 	gtk_widget_show(item);
 	gtk_menu_shell_append(GTK_MENU_SHELL(menu), item);
 
-	// Add checkbutton
 	item = gtk_check_menu_item_new_with_mnemonic(_("_Show HMAC Key"));
+	// Add checkbutton
 	gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(item),
 		gtk_entry_get_visibility(entry));
 	gtk_widget_show(item);
@@ -584,7 +591,9 @@ void callbacks_init(void)
 	CON(gui.entry_hmac_file,                "changed",             gui_clear_digests);
 	CON(gui.entry_hmac_text,                "changed",             hash_string);
 	CON(gui.entry_check_file,               "changed",             gui_check_digests);
+	CON(gui.entry_check_file,               "icon-press",          on_entry_check_icon_press);
 	CON(gui.entry_check_text,               "changed",             gui_check_digests);
+	CON(gui.entry_check_text,               "icon-press",          on_entry_check_icon_press);
 	CON(gui.toolbutton_add,                 "clicked",             on_toolbutton_add_clicked);
 	CON(gui.toolbutton_remove,              "clicked",             list_remove_selection);
 	CON(gui.toolbutton_clear,               "clicked",             list_clear);
@@ -600,6 +609,7 @@ void callbacks_init(void)
 	CON(gui.button_stop,                    "clicked",             gui_stop_hash);
 	CON(gui.dialog,                         "delete-event",        G_CALLBACK(on_dialog_delete_event));
 	CON(gui.dialog_button_close,            "clicked",             G_CALLBACK(on_dialog_delete_event));
+	CON(gui.dialog_togglebutton_show_hmac,  "toggled",             gui_update);
 	CON(gui.dialog_combobox,                "changed",             on_dialog_combobox_changed);
 
 	for (int i = 0; i < HASH_FUNCS_N; i++) {
@@ -607,7 +617,9 @@ void callbacks_init(void)
 			continue;
 
 		CON(gui.hash_widgets[i].button, "toggled", gui_update);
-		g_signal_connect_swapped(gui.hash_widgets[i].menuitem_treeview_copy,
+		g_signal_connect(gui.hash_widgets[i].label_file, "clicked",
+			G_CALLBACK(on_button_hash_clicked), &hash.funcs[i]);
+		g_signal_connect(gui.hash_widgets[i].menuitem_treeview_copy,
 			"activate", G_CALLBACK(on_menuitem_treeview_copy_activate),
 			&hash.funcs[i]);
 	}
