@@ -1,5 +1,5 @@
 /*
- *   Copyright (C) 2007-2016 Tristan Heaven <tristan@tristanheaven.net>
+ *   Copyright (C) 2007-2022 Tristan Heaven <tristan@tristanheaven.net>
  *
  *   This file is part of GtkHash.
  *
@@ -45,9 +45,10 @@ static bool gtkhash_hash_lib_glib_set_type(const enum hash_func_e id,
 		case HASH_FUNC_MD5:    *type = G_CHECKSUM_MD5;    break;
 		case HASH_FUNC_SHA1:   *type = G_CHECKSUM_SHA1;   break;
 		case HASH_FUNC_SHA256: *type = G_CHECKSUM_SHA256; break;
-#if GLIB_CHECK_VERSION(2,35,3)
-		case HASH_FUNC_SHA512: *type = G_CHECKSUM_SHA512; break;
+#if GLIB_CHECK_VERSION(2,51,3)
+		case HASH_FUNC_SHA384: *type = G_CHECKSUM_SHA384; break;
 #endif
+		case HASH_FUNC_SHA512: *type = G_CHECKSUM_SHA512; break;
 
 		default:
 			return false;
@@ -64,7 +65,7 @@ bool gtkhash_hash_lib_glib_is_supported(const enum hash_func_e id)
 		return false;
 
 	if (G_UNLIKELY(g_checksum_type_get_length(type) < 0)) {
-		g_warning("g_checksum_type_get_length() failed (%d)", id);
+		g_debug("g_checksum_type_get_length() failed (%d)", id);
 		return false;
 	}
 
@@ -98,6 +99,7 @@ uint8_t *gtkhash_hash_lib_glib_finish(struct hash_func_s *func, size_t *size)
 {
 	gsize len = g_checksum_type_get_length(LIB_DATA->type);
 	g_assert(len > 0);
+
 	uint8_t *digest = g_malloc(len);
 	g_checksum_get_digest(LIB_DATA->checksum, digest, &len);
 
