@@ -1,5 +1,5 @@
 /*
- *   Copyright (C) 2007-2013 Tristan Heaven <tristanheaven@gmail.com>
+ *   Copyright (C) 2007-2016 Tristan Heaven <tristan@tristanheaven.net>
  *
  *   This file is part of GtkHash.
  *
@@ -14,7 +14,7 @@
  *   GNU General Public License for more details.
  *
  *   You should have received a copy of the GNU General Public License
- *   along with GtkHash. If not, see <http://www.gnu.org/licenses/>.
+ *   along with GtkHash. If not, see <https://gnu.org/licenses/gpl-2.0.txt>.
  */
 
 #ifndef GTKHASH_HASH_HMAC_H
@@ -30,7 +30,7 @@
 #include "hash-func.h"
 
 void gtkhash_hmac_start(struct hash_func_s *func, const uint8_t *key,
-	const size_t key_size);
+	size_t key_size);
 void gtkhash_hmac_stop(struct hash_func_s *func);
 void gtkhash_hmac_finish(struct hash_func_s *func);
 
