@@ -1,5 +1,5 @@
 /*
- *   Copyright (C) 2007-2016 Tristan Heaven <tristan@tristanheaven.net>
+ *   Copyright (C) 2007-2020 Tristan Heaven <tristan@tristanheaven.net>
  *
  *   This file is part of GtkHash.
  *
@@ -23,7 +23,7 @@
 #include "properties.h"
 
 void gtkhash_properties_hash_start(struct page_s *page,
-	const uint8_t *hmac_key, size_t key_size);
+	struct hash_func_s *func, const uint8_t *hmac_key, size_t key_size);
 void gtkhash_properties_hash_stop(struct page_s *page);
 int gtkhash_properties_hash_funcs_supported(struct page_s *page);
 void gtkhash_properties_hash_init(struct page_s *page);
